@@ -1,7 +1,6 @@
 import re
 from typing import List, Union, Optional, Callable, Tuple, Pattern, Any, Dict
 from urllib.parse import parse_qs
-import warnings
 
 import httpx
 
@@ -87,7 +86,6 @@ class _RequestMatcher:
 class HTTPXMock:
     def __init__(self) -> None:
         self._requests: List[httpx.Request] = []
-        self._responses: List[Tuple[_RequestMatcher, httpx.Response]] = []
         self._callbacks: List[
             Tuple[
                 _RequestMatcher,
@@ -104,10 +102,7 @@ class HTTPXMock:
         text: Optional[str] = None,
         html: Optional[str] = None,
         stream: Any = None,
-        data: dict = None,
-        files: Any = None,
         json: Any = None,
-        boundary: bytes = None,
         **matchers,
     ) -> None:
         """
@@ -120,10 +115,7 @@ class HTTPXMock:
         :param text: HTTP body of the response (as string).
         :param html: HTTP body of the response (as HTML string content).
         :param stream: HTTP body of the response (as httpx.SyncByteStream or httpx.AsyncByteStream) as stream content.
-        :param data: HTTP multipart body of the response (as a dictionary) if files is provided.
-        :param files: Multipart files.
         :param json: HTTP body of the response (if JSON should be used as content type) if data is not provided.
-        :param boundary: Multipart boundary if files is provided.
         :param url: Full URL identifying the request(s) to match.
         Can be a str, a re.Pattern instance or a httpx.URL instance.
         :param method: HTTP method identifying the request(s) to match.
@@ -138,13 +130,9 @@ class HTTPXMock:
             content=content,
             text=text,
             html=html,
-            stream=_httpx_internals.multipart_stream(
-                data=data, files=files, boundary=boundary
-            )
-            if files
-            else stream,
+            stream=stream,
         )
-        self._responses.append((_RequestMatcher(**matchers), response))
+        self.add_callback(lambda request: response, **matchers)
 
     def add_callback(
         self, callback: Callable[[httpx.Request], Optional[httpx.Response]], **matchers
@@ -187,26 +175,24 @@ class HTTPXMock:
     ) -> httpx.Response:
         self._requests.append(request)
 
-        response = self._get_response(request)
-        if not response:
-            callback = self._get_callback(request)
-            if callback:
-                response = callback(request)
+        callback = self._get_callback(request)
+        if callback:
+            response = callback(request)
 
-        if response:
-            # Allow to read the response on client side
-            response.is_stream_consumed = False
-            response.is_closed = False
-            if hasattr(response, "_content"):
-                del response._content
-            return response
+            if response:
+                # Allow to read the response on client side
+                response.is_stream_consumed = False
+                response.is_closed = False
+                if hasattr(response, "_content"):
+                    del response._content
+                return response
 
         raise httpx.TimeoutException(
             self._explain_that_no_response_was_found(request), request=request
         )
 
     def _explain_that_no_response_was_found(self, request: httpx.Request) -> str:
-        matchers = [matcher for matcher, _ in self._responses + self._callbacks]
+        matchers = [matcher for matcher, _ in self._callbacks]
         expect_headers = set(
             [
                 header
@@ -233,28 +219,6 @@ class HTTPXMock:
 
         return message
 
-    def _get_response(self, request: httpx.Request) -> Optional[httpx.Response]:
-        responses = [
-            (matcher, response)
-            for matcher, response in self._responses
-            if matcher.match(request)
-        ]
-
-        # No response match this request
-        if not responses:
-            return None
-
-        # Responses match this request
-        for matcher, response in responses:
-            # Return the first not yet called
-            if not matcher.nb_calls:
-                matcher.nb_calls += 1
-                return response
-
-        # Or the last registered
-        matcher.nb_calls += 1
-        return response
-
     def _get_callback(
         self, request: httpx.Request
     ) -> Optional[Callable[[httpx.Request], Optional[httpx.Response]]]:
@@ -310,7 +274,7 @@ class HTTPXMock:
         return requests[0] if requests else None
 
     def reset(self, assert_all_responses_were_requested: bool) -> None:
-        not_called = self._reset_responses() + self._reset_callbacks()
+        not_called = self._reset_callbacks()
 
         if assert_all_responses_were_requested:
             matchers_description = "\n".join([str(matcher) for matcher in not_called])
@@ -319,13 +283,6 @@ class HTTPXMock:
                 not not_called
             ), f"The following responses are mocked but not requested:\n{matchers_description}"
 
-    def _reset_responses(self) -> List[_RequestMatcher]:
-        responses_not_called = [
-            matcher for matcher, _ in self._responses if not matcher.nb_calls
-        ]
-        self._responses.clear()
-        return responses_not_called
-
     def _reset_callbacks(self) -> List[_RequestMatcher]:
         callbacks_not_executed = [
             matcher for matcher, _ in self._callbacks if not matcher.nb_calls
